-- Code to help with UI rescaling. 

-- Given a base filename, width & height, returns a new filename
-- for the game to use.
-- Argument 1: baseFilename {string} Base filename, e.g "bznopause_game" Note - has no .cfg on the end
-- Argument 2: width {number} Current screen/window width, in pixels
-- Argument 3: width {number} Current screen/window height, in pixels
--
-- Returns: {string} Filename to try and load. 
--    If the returned filename does not exist, BZ2 will use baseFilename instead.
--    If the returned filename does exist, and is identical (using case-sensitive check) to baseFilename, will fall thru to the per-resolution check.
--     => if you do want it to skip the per-resolution check, then flip case on a letter or few.
function DetermineShellCfgFile(baseFilename, width, height)
	if((width >= (640 * 3)) and (height >= (480 * 3))) then
		return baseFilename .. "_x3_0";
	elseif((width >= (640 * 2.5)) and (height >= (480 * 2.5))) then						
		return baseFilename .. "_x2_5";
	elseif((width >= (640 * 2)) and (height >= (480 * 2))) then
		return baseFilename .. "_x2_0";
	elseif((width >= (640 * 1.5)) and (height >= (480 * 1.5))) then
		return baseFilename .. "_x1_5";
    else
		return baseFilename;
    end
end

-- Given a base filename, width & height, returns a new filename
-- for the game to use.
-- Argument 1: baseFilename {string} Base filename, e.g "bznopause_game" Note - has no .cfg on the end
-- Argument 2: width {number} Current screen/window width, in pixels
-- Argument 3: width {number} Current screen/window height, in pixels
-- Argument 4: userUIScale {number} User's preference for rescaling. Possible values are 0: *1.0, 1: *1.5, 2: *2.0, 3: *2.5, 4:*3.0
--
-- Returns: {string} Filename to try and load. 
--    If the returned filename does not exist, BZ2 will use baseFilename instead.
--    If the returned filename does exist, and is identical (using case-sensitive check) to baseFilename, will fall thru to the per-resolution check.
--     => if you do want it to skip the per-resolution check, then flip case on a letter or few.
function DetermineGameCfgFile(baseFilename, width, height, userUIScale)
	if(userUIScale == 4) then
		return baseFilename .. "_x3_0";
	elseif(userUIScale == 3) then
		return baseFilename .. "_x2_5";
	elseif(userUIScale == 2) then
		return baseFilename .. "_x2_0";
	elseif(userUIScale == 1) then
		return baseFilename .. "_x1_5";
    else
		return baseFilename;
    end
end
